@@ -65,7 +65,7 @@ class TestBayesianGenerator(TestCase):
         import numpy as np
 
         test_samples = pd.DataFrame(np.linspace(0, 3.14, 10), columns=["x1"])
-        X.submit_data(test_samples)
+        X.evaluate_data(test_samples)
 
         # create gp model with data
         model = gen.train_model(X.data)
@@ -110,3 +110,22 @@ class TestBayesianGenerator(TestCase):
         assert torch.allclose(outputs, true_outputs)
 
     # TODO: test passing UCB options to bayesian exploration
+
+    @patch.multiple(BayesianGenerator, __abstractmethods__=set())
+    def test_get_bounds(self):
+        gen = BayesianGenerator(TEST_VOCS_BASE)
+        bounds = gen._get_bounds()
+        assert torch.allclose(bounds, torch.tensor(TEST_VOCS_BASE.bounds))
+
+        # test with max_travel_distances specified but no data
+        defaults = BayesianGenerator.default_options()
+        defaults.optim.max_travel_distances = [0.1, 0.2]
+        gen = BayesianGenerator(TEST_VOCS_BASE, defaults)
+        with pytest.raises(ValueError):
+            gen._get_bounds()
+
+        # test with max_travel_distances specified and data
+        gen = BayesianGenerator(TEST_VOCS_BASE, defaults)
+        gen.add_data(pd.DataFrame({"x1": [0.5], "x2": [5.0], "y1": [0.5], "c1": [0.5]}))
+        bounds = gen._get_bounds()
+        assert torch.allclose(bounds, torch.tensor([[0.4, 3.0], [0.6, 7.0]]).to(bounds))
