@@ -4,10 +4,12 @@ from xopt.generators.bayesian.mobo import MOBOGenerator
 from xopt.generators.bayesian.upper_confidence_bound import (
     UpperConfidenceBoundGenerator,
 )
+from xopt.generators.bayesian.expected_improvement import ExpectedImprovementGenerator
 
 __all__ = [
     "BayesianGenerator",
     "BayesianExplorationGenerator",
     "MOBOGenerator",
     "UpperConfidenceBoundGenerator",
+    "ExpectedImprovementGenerator",
 ]
