@@ -12,6 +12,7 @@ from xopt.generators.bayesian.objectives import (
 from xopt.generators.bayesian.options import AcqOptions, BayesianOptions
 from xopt.generators.bayesian.time_dependent import (
     TDAcqOptions,
+    TDModelOptions,
     TimeDependentBayesianGenerator,
 )
 from xopt.vocs import VOCS
@@ -31,12 +32,13 @@ class UCBOptions(BayesianOptions):
 
 class TDUCBOptions(UCBOptions):
     acq = TDUpperConfidenceBoundOptions()
+    model = TDModelOptions()
 
 
 class UpperConfidenceBoundGenerator(BayesianGenerator):
     alias = "upper_confidence_bound"
 
-    def __init__(self, vocs: VOCS, options: UCBOptions = UCBOptions()):
+    def __init__(self, vocs: VOCS, options: UCBOptions = None):
         """
         Generator using UpperConfidenceBound acquisition function
 
@@ -48,13 +50,14 @@ class UpperConfidenceBoundGenerator(BayesianGenerator):
         options: UpperConfidenceBoundOptions
             Specific options for this generator
         """
+        options = options or UCBOptions()
         if not isinstance(options, UCBOptions):
             raise ValueError("options must be a UCBOptions object")
 
         if vocs.n_objectives != 1:
             raise ValueError("vocs must have one objective for optimization")
 
-        super(UpperConfidenceBoundGenerator, self).__init__(vocs, options)
+        super().__init__(vocs, options)
 
     @staticmethod
     def default_options() -> UCBOptions:
@@ -72,7 +75,9 @@ class UpperConfidenceBoundGenerator(BayesianGenerator):
         )
 
         cqUCB = ConstrainedMCAcquisitionFunction(
-            model, qUCB, create_constraint_callables(self.vocs), infeasible_cost=0.0
+            model,
+            qUCB,
+            create_constraint_callables(self.vocs),
         )
 
         return cqUCB
@@ -83,7 +88,11 @@ class TDUpperConfidenceBoundGenerator(
 ):
     alias = "time_dependent_upper_confidence_bound"
 
-    def __init__(self, vocs: VOCS, options: TDUCBOptions = TDUCBOptions()):
+    def __init__(self, vocs: VOCS, options: TDUCBOptions = None):
+        options = options or TDUCBOptions()
+        if not isinstance(options, UCBOptions):
+            raise ValueError("options must be a TDUCBOptions object")
+
         super(TDUpperConfidenceBoundGenerator, self).__init__(vocs, options)
 
     @staticmethod
