@@ -7,8 +7,11 @@ class RandomGenerator(Generator):
 
     alias = "random"
 
-    def __init__(self, vocs, options: GeneratorOptions = GeneratorOptions()):
-        super(RandomGenerator, self).__init__(vocs, options)
+    def __init__(self, vocs, options: GeneratorOptions = None):
+        options = options or GeneratorOptions()
+        if not isinstance(options, GeneratorOptions):
+            raise ValueError("options must be of type GeneratorOptions")
+        super().__init__(vocs, options)
 
     @staticmethod
     def default_options() -> GeneratorOptions:
